import { PrismaClient } from '@prisma/client';
import { genSalt, hash } from 'bcryptjs';

const prisma = new PrismaClient();

const userSeeds = (
    name: string, 
    position_id: number, 
    dept_id: number
  ) => {
  const user = {
    email: `${name}${dept_id - 1}@salmanitb.com`,
    dept_id: dept_id,
    position_id: position_id,
    password: `${name}${dept_id - 1}`,
    status: 1
  }

  return user;
}

const main = async () => {
  console.log('Start seeding...');

  try {
    // User (Director)
    const director = {
      email: 'director@salmanitb.com',
      password: 'director',
      position_id: 1,
      dept_id: 1,
      status: 1
    }

    director.password = await hash(director.password, await genSalt(10));

    await prisma.user.create({
      data: director
    });

    const position = [
      'manager',
      'assistantmanager',
      'supervisor',
      'staff',
    ];

    // Manager: 3, AssistantManager: 3, Supervisor: 3, Staff: 10
    for (let i = 0; i < 4; i++) {
      for (let j = 0; j < 3; j++) {
        const user = userSeeds(position[i], i + 2, j + 2)
        user.password = await hash(user.password, await genSalt(10));

        await prisma.user.create({
          data: user
        });
      }
    }
  } catch (error) {
    console.error('Error while seeding data:', error);
  } finally {
    await prisma.$disconnect();

    console.log("Seeding successful");
  }
}

main().catch(async (err) => {
  console.error('Script execution failed:', err);
});