import { UserController } from '@controllers/user.controller';
import { RequestWithUser } from '@interfaces/auth.interface';
import { Routes } from '@interfaces/route.interface';
import { AuthMiddleware, ValidationMiddleware } from '@middlewares/index';
import { UserService } from '@services/user.service';
import { addUserSchema, resetPasswordSchema } from '@dtos/user.dto';
import { Response, NextFunction, Router } from 'express';
import { ApiService } from 'types/http';

export class UserRoute implements Routes {
  public router = Router();
  private userService = new UserService();
  private userController = new UserController(this.userService);

  constructor() {
    this.initializeRoutes();
  }

  private initializeRoutes() {
    this.router.post(
      '/user', 
      (req: RequestWithUser, res: Response, next: NextFunction) => {
        AuthMiddleware.authenticateTokenFromService(
          req, res, next, ApiService.KINERJA_SERVICE
        );
      },
      ValidationMiddleware.validate(addUserSchema), 
      ValidationMiddleware.exceptionGuard(this.userController.addUserFromService)
    );

    this.router.patch(
      '/user/reset-password',
      (req: RequestWithUser, res: Response, next: NextFunction) => {
        AuthMiddleware.authenticateTokenFromService(
          req, res, next, ApiService.KINERJA_SERVICE
        );
      },
      ValidationMiddleware.validate(resetPasswordSchema), 
      ValidationMiddleware.exceptionGuard(this.userController.resetPasswordFromService)
    )
  }
}
